import test from 'ava';
import valid from '../';

test('Affirmative', (t) => {
  t.is(valid.affirmative('YES'), true);
  t.is(valid.affirmative('Yes'), true);
  t.is(valid.affirmative('yes'), true);
  t.is(valid.affirmative('Y'), true);
  t.is(valid.affirmative('y'), true);
  t.is(valid.affirmative('ON'), true);
  t.is(valid.affirmative('On'), true);
  t.is(valid.affirmative('on'), true);
  t.is(valid.affirmative('OK'), true);
  t.is(valid.affirmative('Ok'), true);
  t.is(valid.affirmative('ok'), true);
  t.is(valid.affirmative('OKAY'), true);
  t.is(valid.affirmative('Okay'), true);
  t.is(valid.affirmative('okay'), true);
  t.is(valid.affirmative('TRUE'), true);
  t.is(valid.affirmative('True'), true);
  t.is(valid.affirmative('true'), true);
  t.is(valid.affirmative('true '), true);
  t.is(valid.affirmative('T'), true);
  t.is(valid.affirmative('t'), true);

  t.is(valid.affirmative('f'), false);
  t.is(valid.affirmative('F'), false);
  t.is(valid.affirmative('O'), false);
  t.is(valid.affirmative('o'), false);
  t.is(valid.affirmative('no'), false);
  t.is(valid.affirmative(''), false);
  t.is(valid.affirmative('test'), false);
});

test('AlphaNumeric', (t) => {
  t.is(valid.alphaNumeric('12345'), true);
  t.is(valid.alphaNumeric('test'), true);
  t.is(valid.alphaNumeric('TEST'), true);
  t.is(valid.alphaNumeric('12345TEST12345'), true);

  t.is(valid.alphaNumeric(''), false);
  t.is(valid.alphaNumeric('à'), false);
  t.is(valid.alphaNumeric('Tést'), false);
  t.is(valid.alphaNumeric('$'), false);
  t.is(valid.alphaNumeric('asd$123'), false);
  t.is(valid.alphaNumeric('asd-123'), false);
  t.is(valid.alphaNumeric('asd_123'), false);
  t.is(valid.alphaNumeric('asd 123'), false);
  t.is(valid.alphaNumeric('asd@123'), false);
  t.is(valid.alphaNumeric('asd.'), false);
});


test('Alpha (alphabetic)', (t) => {
  t.is(valid.alpha('test'), true);
  t.is(valid.alpha('TEST'), true);

  t.is(valid.alpha(''), false);
  t.is(valid.alpha('12345TEST12345'), false);
  t.is(valid.alpha('12345'), false);
  t.is(valid.alpha('à'), false);
  t.is(valid.alpha('Tést'), false);
  t.is(valid.alpha('$'), false);
  t.is(valid.alpha('asd$123'), false);
  t.is(valid.alpha('asd-123'), false);
  t.is(valid.alpha('asd_123'), false);
  t.is(valid.alpha('asd 123'), false);
  t.is(valid.alpha(' test'), false);
  t.is(valid.alpha('asd asd'), false);
  t.is(valid.alpha('asd@123'), false);
  t.is(valid.alpha('asd.'), false);
});

test('Email', (t) => {
  t.is(valid.email('test@test.com'), true);

  t.is(valid.email(''), false);
  t.is(valid.email('test'), false);
  t.is(valid.email('test.com'), false);
  t.is(valid.email('test@test'), false);
  t.is(valid.email('test@test.'), false);
  t.is(valid.email('test email@test.com'), false);
  t.is(valid.email('mailto:test@test.com'), false);
});


test('Negatory', (t) => {
  t.is(valid.negatory('NO'), true);
  t.is(valid.negatory('No'), true);
  t.is(valid.negatory('no'), true);
  t.is(valid.negatory('N'), true);
  t.is(valid.negatory('n'), true);
  t.is(valid.negatory('OFF'), true);
  t.is(valid.negatory('Off'), true);
  t.is(valid.negatory('off'), true);
  t.is(valid.negatory('FALSE'), true);
  t.is(valid.negatory('False'), true);
  t.is(valid.negatory('false'), true);
  t.is(valid.negatory('F'), true);
  t.is(valid.negatory('f'), true);
  t.is(valid.negatory('false '), true);

  t.is(valid.negatory('O'), false);
  t.is(valid.negatory('o'), false);
  t.is(valid.negatory('0'), false);
  t.is(valid.negatory('test'), false);
});


test('Numeric String', (t) => {
  t.is(valid.numeric('0'), true);
  t.is(valid.numeric('123'), true);
  t.is(valid.numeric('-123'), true);
  t.is(valid.numeric('123.123'), true);

  t.is(valid.numeric(''), false);
  t.is(valid.numeric('test'), false);
  t.is(valid.numeric('123px'), false);
  t.is(valid.numeric('123%'), false);
  t.is(valid.numeric('$123'), false);
  t.is(valid.numeric('123,000'), false);
  t.is(valid.numeric('123.123.123'), false);
});

test('Social Security Number', (t) => {
  t.is(valid.socialSecurity('078-05-1120'), true); // from wikipedia

  t.is(valid.socialSecurity('XXX-XX-XXXX'), false);
  t.is(valid.socialSecurity('000-00-0000'), false);
  t.is(valid.socialSecurity('000-05-1120'), false);
  t.is(valid.socialSecurity('078-00-1120'), false);
  t.is(valid.socialSecurity('078-05-0000'), false);
  t.is(valid.socialSecurity('078051120'), false);
});


test('Value String', (t) => {
  t.is(valid.value('0'), true);
  t.is(valid.value('-0'), true);
  t.is(valid.value('+0'), true);
  t.is(valid.value('123'), true);
  t.is(valid.value('-123'), true);
  t.is(valid.value('+123'), true);
  t.is(valid.value('123.123'), true);
  t.is(valid.value('123px'), true);
  t.is(valid.value('123BTC'), true);
  t.is(valid.value('123 BTC'), true);
  t.is(valid.value('123%'), true);
  t.is(valid.value('$123'), true);
  t.is(valid.value('123-123'), true);
  t.is(valid.value('123,000'), true);
  t.is(valid.value('123,000.00'), true);
  t.is(valid.value('(123)'), true);
  t.is(valid.value('#000000'), true);

  t.is(valid.value(''), false);
  t.is(valid.value('NaN'), false);
  t.is(valid.value('test'), false);
  t.is(valid.value('te123st'), false);
  t.is(valid.value('Infinity'), false);
  t.is(valid.value('-'), false);
  t.is(valid.value('+'), false);
});


test('URL', (t) => {
  t.is(valid.url('https://test.com'), true);
  t.is(valid.url('http://test.com'), true);
  t.is(valid.url('http://test.com:3000'), true);
  t.is(valid.url('http://test.com/path'), true);
  t.is(valid.url('http://test.com/path/'), true);
  t.is(valid.url('http://test.com/path/to/img.jpg'), true);
  t.is(valid.url('http://test.com:3000/path/to/img.jpg'), true);
  t.is(valid.url('http://4.35.153.221'), true);
  t.is(valid.url('http://4.35.153.221/'), true);
  t.is(valid.url('https://4.35.153.221/'), true);
  t.is(valid.url('https://4.35.153.221:3000'), true);
  t.is(valid.url('https://4.35.153.221:3000/path'), true);

  t.is(valid.url(''), false);
  t.is(valid.url('test'), false);
  t.is(valid.url('test.com'), false);
  t.is(valid.url('www.test.com'), false);
  t.is(valid.url('http:/test.com'), false);
  t.is(valid.url('http//test.com'), false);
  t.is(valid.url('4.35.153.221'), false);
  t.is(valid.url('http://300.35.153.221'), false);
});

test('Zip Code', (t) => {
  t.is(valid.zipCode('89052'), true);
  t.is(valid.zipCode('01001'), true);
  t.is(valid.zipCode('00501'), true);

  t.is(valid.zipCode('0'), false);
  t.is(valid.zipCode('foo'), false);
  t.is(valid.zipCode('00000'), false);
  t.is(valid.zipCode('00001'), false);
  t.is(valid.zipCode('00500'), false);
  t.is(valid.zipCode('-89052'), false);
  t.is(valid.zipCode('89052-'), false);
  t.is(valid.zipCode('89052-658'), false);
  t.is(valid.zipCode('890526589'), false);
  t.is(valid.zipCode('123456'), false);
  t.is(valid.zipCode('01001-6589'), false);
  t.is(valid.zipCode('00501-6589'), false);
  t.is(valid.zipCode('89052-6589'), false);
});

test('Zip Code + 4', (t) => {
  t.is(valid.zipCodeLong('89052'), true);
  t.is(valid.zipCodeLong('01001'), true);
  t.is(valid.zipCodeLong('00501'), true);
  t.is(valid.zipCodeLong('01001-6589'), true);
  t.is(valid.zipCodeLong('00501-6589'), true);
  t.is(valid.zipCodeLong('89052-6589'), true);

  t.is(valid.zipCodeLong('0'), false);
  t.is(valid.zipCodeLong('foo'), false);
  t.is(valid.zipCodeLong('00000'), false);
  t.is(valid.zipCodeLong('00001'), false);
  t.is(valid.zipCodeLong('00500'), false);
  t.is(valid.zipCodeLong('-89052'), false);
  t.is(valid.zipCodeLong('89052-'), false);
  t.is(valid.zipCodeLong('89052-658'), false);
  t.is(valid.zipCodeLong('890526589'), false);
  t.is(valid.zipCodeLong('123456'), false);
});

test('Credit Card: Generic', (t) => {
  t.is(valid.card.generic('4222222222222'), true);    // visa
  t.is(valid.card.generic('4111111111111111'), true); // visa
  t.is(valid.card.generic('4242424242424242'), true); // visa
  t.is(valid.card.generic('378282246310005'), true);  // amex
  t.is(valid.card.generic('371449635398431'), true);  // amex
  t.is(valid.card.generic('378734493671000'), true);  // amex corporate
  t.is(valid.card.generic('6011111111111117'), true); // discover
  t.is(valid.card.generic('6011000990139424'), true); // discover
  t.is(valid.card.generic('5555555555554444'), true); // mastercard
  t.is(valid.card.generic('5105105105105100'), true); // mastercard
  t.is(valid.card.generic('3530111333300000'), true); // jcb
  t.is(valid.card.generic('3566002020360505'), true); // jcb
  t.is(valid.card.generic('6331101999990016'), true); // switch / solo
  t.is(valid.card.generic('38000000000006'), true);   // carte blanche
  t.is(valid.card.generic('30569309025904'), true);   // diners club
  t.is(valid.card.generic('38520000023237'), true);   // diners club
  t.is(valid.card.generic('6304850000000040'), true); // laser card
  t.is(valid.card.generic('6304850000000602'), true); // laser card
  t.is(valid.card.generic('6240008631401148'), true); // unionpay
  t.is(valid.card.generic('6759649826438453'), true); // maestro
  t.is(valid.card.generic('6759000000000000'), true); // maestro uk
  t.is(valid.card.generic('6799990100000000019'), true); // maestro
  t.is(valid.card.generic('5610591081018250'), true); // australian bankcard (not in any regexp)

  t.is(valid.card.generic('1234123412341234'), false);
  t.is(valid.card.generic('1'), false);
  t.is(valid.card.generic('123456789012345678901234567890'), false);

  t.is(valid.creditCard('4222222222222'), true);    // visa (.creditCard() alias)
  t.is(valid.creditCard('1'), false);
});




test('Credit Card: Mastercard', (t) => {
  t.is(valid.card.mastercard('5555555555554444'), true);  // mastercard
  t.is(valid.card.mastercard('5105105105105100'), true);  // mastercard
  t.is(valid.card.mastercard('4222222222222'), false);    // visa
  t.is(valid.card.mastercard('4111111111111111'), false); // visa
  t.is(valid.card.mastercard('4242424242424242'), false); // visa
  t.is(valid.card.mastercard('378282246310005'), false);  // amex
});

test('Credit Card: Visa', (t) => {
  t.is(valid.card.visa('4222222222222'), true);    // visa
  t.is(valid.card.visa('4111111111111111'), true); // visa
  t.is(valid.card.visa('4242424242424242'), true); // visa
  t.is(valid.card.visa('5555555555554444'), false); // mastercard
  t.is(valid.card.visa('5105105105105100'), false); // mastercard
  t.is(valid.card.visa('378282246310005'), false); // amex
});

test('Credit Card: Amex', (t) => {
  t.is(valid.card.amex('378282246310005'), true);   // amex
  t.is(valid.card.amex('371449635398431'), true);   // amex
  t.is(valid.card.amex('378734493671000'), true);   // amex corporate
  t.is(valid.card.amex('4111111111111111'), false); // visa
});

test('Credit Card: Discover', (t) => {
  t.is(valid.card.discover('6011111111111117'), true);  // discover
  t.is(valid.card.discover('6011000990139424'), true);  // discover
  t.is(valid.card.discover('4111111111111111'), false); // visa
});

test('Credit Card: JCB', (t) => {
  t.is(valid.card.jcb('3530111333300000'), true);  // jcb
  t.is(valid.card.jcb('3566002020360505'), true);  // jcb
  t.is(valid.card.jcb('4111111111111111'), false); // visa
});

test('Credit Card: Switch/Solo', (t) => {
  t.is(valid.card.solo('6331101999990016'), true);  // switch / solo
  t.is(valid.card.solo('4111111111111111'), false); // visa
});

test('Credit Card: Carte Blanche', (t) => {
  t.is(valid.card.carteBlanche('38000000000006'), true);    // carte blanche
  t.is(valid.card.carteBlanche('4111111111111111'), false); // visa
});

test('Credit Card: Diners Club', (t) => {
  t.is(valid.card.dinersClub('30569309025904'), true);   // diners club
  t.is(valid.card.dinersClub('38520000023237'), true);   // diners club
  t.is(valid.card.dinersClub('4111111111111111'), false); // visa
});

test('Credit Card: Laser Card', (t) => {
  t.is(valid.card.lasercard('6304850000000040'), true); // laser card
  t.is(valid.card.lasercard('6304850000000602'), true); // laser card
  t.is(valid.card.lasercard('4111111111111111'), false); // visa
});

test('Credit Card: Unionpay', (t) => {
  t.is(valid.card.unionpay('6240008631401148'), true); // unionpay
  t.is(valid.card.unionpay('4111111111111111'), false); // visa
});

test('Credit Card: Maestro', (t) => {
  t.is(valid.card.maestro('6759649826438453'), true); // maestro
  t.is(valid.card.maestro('6759000000000000'), true); // maestro uk
  t.is(valid.card.maestro('6799990100000000019'), true); // maestro
  t.is(valid.card.maestro('4111111111111111'), false); // visa
});
